@@ -1,5 +1,6 @@
 import turtle
 
+  
 def screensize(a,b):
   turtle.screensize(a,b)
 
@@ -32,3 +33,25 @@ def turn_right(a):
 
 def startdraw():
   turtle.screensize(500,500)
+
+def penup():
+  turtle.penup()
+
+def pendown():
+  turtle.pendown()
+
+def tp(x,y):
+  turtle.goto(x,y)
+
+def tpx(x):
+  turtle.setx(x)
+
+def tpy(y):
+  turtle.sety(y)
+
+def getposition():
+  position = turtle.pos()
+  return position
+
+def printposition():
+  print(turtle.pos())
